@@ -1,10 +1,10 @@
-<?php
+<?php declare(strict_types=1);
 
 namespace Tests\Nyholm\Psr7\Integration;
 
-use Psr\Http\Message\RequestInterface;
 use Http\Psr7Test\RequestIntegrationTest;
 use Nyholm\Psr7\Request;
+use Psr\Http\Message\RequestInterface;
 
 class RequestTest extends RequestIntegrationTest
 {
