@@ -1,10 +1,10 @@
-<?php
+<?php declare(strict_types=1);
 
 namespace Tests\Nyholm\Psr7\Integration;
 
-use Psr\Http\Message\ResponseInterface;
 use Http\Psr7Test\ResponseIntegrationTest;
 use Nyholm\Psr7\Response;
+use Psr\Http\Message\ResponseInterface;
 
 class ResponseTest extends ResponseIntegrationTest
 {
